@@ -19,7 +19,16 @@ my $deps = {
 #        { module => 'Provision::Unix'   , info => {} },
         { module => 'URI'               , info => {} },
         { module => 'version'           , info => {} },
+        { module => 'IO::Socket::SSL'   , info => {} },
     ],
+    'apps' => [
+        { app => 'expat'         , info => { port => 'expat2',         dport=>'expat2' } },
+        { app => 'gettext'       , info => { port => 'gettext',        dport=>'gettext'} },
+        { app => 'gmake'         , info => { port => 'gmake',          dport=>'gmake'  } },
+        { app => 'mysql-server-5', info => { port => 'mysql50-server', dport=>'mysql5',  yum => 'mysql-server' } },
+        { app => 'apache22'      , info => { port => 'apache22',       dport=>'',     yum => 'httpd' } },
+        { app => 'mod_perl2'     , info => { port => 'mod_perl2',      dport=>'',     yum => 'mod_perl' } },
+    ]
 };
 
 $EUID == 0 or die( "You will have better luck if you run me as root.\n");
