@@ -1,10 +1,10 @@
 package Mail::Toaster::Apache;
 
-our $VERSION = '5.26';
-
 use strict;
 use warnings;
 
+our $VERSION = '5.33';
+
 use Carp;
 use English qw( -no_match_vars );
 use File::Copy;
@@ -15,11 +15,11 @@ my ( $log, $util, %std_opts );
 
 sub new {
     my $class = shift;
-    my %p = validate( @_, 
+    my %p = validate( @_,
         {   'log' => { type=>OBJECT },
             fatal => { type => BOOLEAN, optional => 1, default => 1 },
             debug => { type => BOOLEAN, optional => 1 },
-        } 
+        }
     );
 
     $log  = $p{'log'};
@@ -33,15 +33,16 @@ sub new {
     my $self = {
         'log' => $log,
         debug => $debug,
-        fatal => $fatal,    
-    };    
+        fatal => $fatal,
+    };
     bless $self, $class;
 
 # globally scoped hash, populated with defaults requested by the caller
     %std_opts = (
         'test_ok' => { type => BOOLEAN, optional => 1 },
         'fatal'   => { type => BOOLEAN, optional => 1, default => $fatal },
-        'debug'   => { type => BOOLEAN, optional => 1, default => $debug },    
+        'debug'   => { type => BOOLEAN, optional => 1, default => $debug },
+        'quiet'   => { type => BOOLEAN, optional => 1, default => 0 },
     );
 
     return $self;
@@ -102,19 +103,19 @@ sub install_1_source {
         $util->syscmd( "./configure --with-apache=../$apache" );
     }
     else {
-        $util->syscmd( 
+        $util->syscmd(
 "./configure --with-apache=../$apache --with-ssl=/usr --enable-shared=ssl --with-mm=/usr/local"
         );
-    }
+    };
 
     chdir("../$mod_perl");
     if ( $OSNAME eq "darwin" ) {
-        $util->syscmd( 
+        $util->syscmd(
 "perl Makefile.PL APACHE_SRC=../$apache NO_HTTPD=1 USE_APACI=1 PREP_HTTPD=1 EVERYTHING=1"
         );
     }
     else {
-        $util->syscmd( 
+        $util->syscmd(
 "perl Makefile.PL DO_HTTPD=1 USE_APACI=1 APACHE_PREFIX=/usr/local EVERYTHING=1 APACI_ARGS='--server-uid=www, --server-gid=www, --enable-module=so --enable-module=most, --enable-shared=max --disable-shared=perl, --enable-module=perl, --with-layout=../$layout:FreeBSD, --without-confadjust'"
         );
     }
@@ -217,9 +218,7 @@ sub install_2 {
         print "\nInstalling Apache 2 on Darwin (MacOS X)?\n\n";
 
         if ( ! -d "/usr/dports/dports" ) {
-            print
-"I can't find DarwinPorts! Try following the instructions here:  
-http://www.tnpi.net/internet/mail/toaster/darwin.shtml.\n";
+            print "I can't find MacPorts! Try installing it.\n";
             return;
         }
 
@@ -351,12 +350,7 @@ sub install_2_freebsd_flags {
 
 sub startup {
     my $self = shift;
-
-    my %p = validate( @_, {
-            'conf'    => { type=>HASHREF, },
-            %std_opts,
-        },
-    );
+    my %p = validate( @_, { 'conf' => { type=>HASHREF }, %std_opts } );
 
     my ( $conf, $fatal, $debug ) = ( $p{'conf'}, $p{'fatal'}, $p{'debug'} );
 
@@ -389,7 +383,7 @@ sub startup_freebsd {
 
     $freebsd->conf_check( check=>"apache2_enable", line=>'apache2_enable="YES"' );
     $freebsd->conf_check( check=>"apache22_enable", line=>'apache22_enable="YES"' );
-    $freebsd->conf_check( 
+    $freebsd->conf_check(
         check=>"apache2ssl_enable", line=>'apache2ssl_enable="YES"' );
 
     my $etcdir = $conf->{'system_config_dir'} || "/usr/local/etc";
@@ -400,7 +394,6 @@ sub startup_freebsd {
 }
 
 sub apache2_fixups {
-
     my ( $self, $conf, $ports_dir ) = @_;
 
     my $prefix = $conf->{'toaster_prefix'}    || "/usr/local";
@@ -442,11 +435,11 @@ sub apache2_install_vhost {
 
     if ( -d "$apache_conf_dir/Includes" ) {
         $full_path = "$apache_conf_dir/Includes/$file_to_write";
-    } 
+    }
     else {
         $full_path = "$apache_conf_dir/$file_to_write";
     };
-    
+
     my $ssl_key = "etc/apache2/ssl.key/server.key";
     my $ssl_crt = "etc/apache2/ssl.crt/server.crt";
 
@@ -471,62 +464,52 @@ sub apache2_install_vhost {
 
     print $MT_CONF <<"EO_MAIL_TOASTER_CONF";
 #
-# Mail-Toaster specific Apache configuration file additions. 
-#   These additions must be made to get Squirrelmail, Isoqlog, 
+# Mail-Toaster specific Apache configuration file additions.
+#   These additions must be made to get Squirrelmail, Isoqlog,
 #   and other toaster features to work.
 #
-# This file is generated automatically, based upon your settings 
-#    in toaster-watcher.conf
+# This file is auto generated, based upon toaster-watcher.conf
 #
-# This should be set in httpd.conf, but is not by default, so we turn it
-# on here.
+# This is not enabled by default in httpd.conf
 NameVirtualHost *:80
 
 <VirtualHost *:80>
     ServerName $hostname
 
-# the redirect effectively requires all users of your email applications to use ssl
-    # connections. This is highly recommended and the default. If you wish to
-    # allow your users to connect and send their passwords in clear text,
-    # thereby allowing Very Naught People[TM] to hijack their accounts and
-    # turn your mail server into a spam relay, then by all means, just go
-    # ahead and comment out this redirect. 
+    # the redirect forces users to use ssl. If you wish to allow users to send
+    # passwords in clear text, enabling Very Naughty People[TM] to hijack their
+    # email account and turn this server into a relay, comment out the redirect.
 
     Redirect / https://$redirect_host/
 
-# these settings are ignored while the  redirect is in force. They
-# are here for those who want access to the email apps without requiring ssl.
-
+# these settings are ignored while the  redirect is in force.
     DocumentRoot $htdocs
     DirectoryIndex index.html
     ScriptAlias /cgi-bin/ "$cgibin/"
 </VirtualHost>
 
-# The asterisks for port 443 vhosts really should be replaced with an IP
-# address.
-<IfModule ssl_module>
-    Listen $local_ip:443
-    NameVirtualHost $local_ip:443
+# Asterisks (if any) for port 443 vhosts should be an IP address.
+Listen $local_ip:443
+NameVirtualHost $local_ip:443
 
-    AddType application/x-x509-ca-cert .crt
-    AddType application/x-pkcs7-crl    .crl
-    SSLPassPhraseDialog  builtin
-    SSLSessionCache        "shmcb:/var/run/ssl_scache(512000)"
-    SSLSessionCacheTimeout  300
-    SSLMutex  "file:/var/run/ssl_mutex"
-    SSLCipherSuite HIGH:!SSLv2
+AddType application/x-x509-ca-cert .crt
+AddType application/x-pkcs7-crl    .crl
+SSLPassPhraseDialog  builtin
+SSLSessionCache        "shmcb:/var/run/ssl_scache(512000)"
+SSLSessionCacheTimeout  300
+SSLMutex  "file:/var/run/ssl_mutex"
+SSLCipherSuite HIGH:!SSLv2
 
-    <VirtualHost $local_ip:443>
-        ServerName $hostname
-        DocumentRoot $htdocs
-        DirectoryIndex index.html
-        ScriptAlias /cgi-bin/ "$cgibin/"
+<VirtualHost $local_ip:443>
+    ServerName $hostname
+    DocumentRoot $htdocs
+    DirectoryIndex index.html
+    ScriptAlias /cgi-bin/ "$cgibin/"
 
-        SSLEngine on
-        SSLCertificateFile $ssl_crt
-        SSLCertificateKeyFile $ssl_key
-    </VirtualHost>
-</IfModule>
+    SSLEngine on
+    SSLCertificateFile $ssl_crt
+    SSLCertificateKeyFile $ssl_key
+</VirtualHost>
 
 # these is an override for the default htdocs
 # the main difference is having ExecCGI enabled
@@ -548,6 +531,8 @@ NameVirtualHost *:80
     Allow from all
 </Directory>
 
+# Sensible defaults & increased security
+HostnameLookups Off
 # don't divulge Apache version. Adds obscurity from scanners
 # looking for vulnerable Apache versions.
 ServerSignature Off
@@ -560,29 +545,34 @@ ServerTokens ProductOnly
     RewriteRule .* - [F]
 </IfModule>
 
-EO_MAIL_TOASTER_CONF
-
-    if ( $conf->{'install_php'} ) {
-        print $MT_CONF "# enable php parsing
+AddHandler cgi-script .cgi
+    # enable php parsing
 AddType application/x-httpd-php .php
 AddType application/x-httpd-php-source .phps
-    ";
-    };
 
-    if ( $conf->{'install_isoqlog'} ) {
-        print $MT_CONF '
 Alias /isoqlog/images/ "/usr/local/share/isoqlog/htmltemp/images/"
 <Directory "/usr/local/share/isoqlog/htmltemp/images">
-    Options None
     AllowOverride None
     Order allow,deny
     Allow from all
 </Directory>
-';
-    };
 
-    if ( $conf->{'install_squirrelmail'} ) {
-        print $MT_CONF '
+<Directory "$htdocs/isoqlog">
+    Options None
+    AllowOverride None
+
+    Order deny,allow
+    deny from all
+    #allow from 216.243.3
+    AuthUserFile /usr/local/etc/WebUsers
+    AuthName "Admins Only"
+    AuthType Digest
+    require valid-user
+    satisfy any
+</Directory>
+
+Alias /qmailadmin/ "$htdocs/qmailadmin/"
+
 Alias /squirrelmail/ "/usr/local/www/squirrelmail/"
 <Directory "/usr/local/www/squirrelmail">
     DirectoryIndex index.php
@@ -591,35 +581,29 @@ Alias /squirrelmail/ "/usr/local/www/squirrelmail/"
     Order allow,deny
     Allow from all
 </Directory>
-';
-    };
 
-    if ( $conf->{'install_phpmyadmin'} ) {
-        print $MT_CONF '
 Alias /phpMyAdmin/ "/usr/local/www/phpMyAdmin/"
 <Directory "/usr/local/www/phpMyAdmin">
     DirectoryIndex index.php
     Options Indexes ExecCGI
     AllowOverride None
-    Order allow,deny
-    Allow from all
+    Order deny,allow
+    deny from all
+    #allow from 216.243.3
+    AuthType Digest
+    AuthName "Admins Only"
+    AuthUserFile /usr/local/etc/WebUsers
+    require valid-user
+    satisfy any
 </Directory>
-';
-    };
 
-    if ( $conf->{'install_rrdutil'} ) {
-        print $MT_CONF '
 Alias /rrdutil/ "/usr/local/rrdutil/html/"
 <Directory "/usr/local/rrdutil/html">
     AllowOverride None
     Order allow,deny
     Allow from all
 </Directory>
-';
-    };
 
-    if ( $conf->{'install_roundcube'} ) {
-        print $MT_CONF '
 Alias /roundcube "/usr/local/www/roundcube/"
 <Directory "/usr/local/www/roundcube">
     DirectoryIndex index.php
@@ -627,10 +611,7 @@ Alias /roundcube "/usr/local/www/roundcube/"
     Order allow,deny
     Allow from all
 </Directory>
-';
-    };
 
-    print $MT_CONF '
 Alias /v-webmail/ "/usr/local/www/v-webmail/htdocs/"
 <Directory "/usr/local/www/v-webmail">
     DirectoryIndex index.php
@@ -638,13 +619,39 @@ Alias /v-webmail/ "/usr/local/www/v-webmail/htdocs/"
     Order allow,deny
     Allow from all
 </Directory>
-';
 
-#    if ($conf->{'install_apache'} == 22 ) {
-#        print $MT_CONF '
-#Alias /icons/ "/usr/local/www/apache22/icons/"
-#';
-#    }
+Alias /images/vqadmin "$htdocs/images/vqadmin"
+<Directory "$cgibin/vqadmin">
+    Options ExecCGI
+    AllowOverride None
+
+    Order deny,allow
+    deny from all
+    #allow from 216.243.3
+    AuthType Digest
+    AuthName "Admins Only"
+    AuthUserFile /usr/local/etc/WebUsers
+    require valid-user
+    satisfy any
+</Directory>
+
+Alias /horde "/usr/local/www/horde/"
+<Directory "/usr/local/www/horde">
+    DirectoryIndex index.php
+    AllowOverride All
+    Order allow,deny
+    Allow from all
+</Directory>
+
+Alias /munin "/usr/local/www/munin"
+<Directory "/usr/local/www/munin">
+    DirectoryIndex index.html
+    AllowOverride All
+    Order allow,deny
+    Allow from all
+</Directory>
+
+EO_MAIL_TOASTER_CONF
 
     close $MT_CONF;
 
@@ -657,14 +664,13 @@ Alias /v-webmail/ "/usr/local/www/v-webmail/htdocs/"
 }
 
 sub freebsd_extras {
-
     my ( $self, $conf, $freebsd ) = @_;
 
     $freebsd->install_port( "cronolog" );
 
     # libwww requires this, so we preemptively install it to supress
     # the dialog box it opens
-    $freebsd->install_port( "p5-Authen-SASL", 
+    $freebsd->install_port( "p5-Authen-SASL",
         options => "#
 # This file was generated by mail-toaster
 # Options for p5-Authen-SASL-2.10_1
@@ -673,29 +679,11 @@ WITHOUT_KERBEROS=true\n",
     );
 
     $freebsd->install_port( "p5-libwww" );
-
-    # php stuff
-    if ( $conf->{'package_install_method'} eq "packages" ) {
-        $freebsd->install_package( "bison" );
-        $freebsd->install_package( "gd"  );
-    }
     $freebsd->install_port( "bison" );
     $freebsd->install_port( "gd"    );
-
-    if ( $conf->{'install_php'} == "5" ) {
-        $freebsd->install_port( "php5",
-            flags => "WITH_APACHE=yes WITH_APACHE2=yes BATCH=yes",
-        );
-    }
-    else {
-        $freebsd->install_port( "php4",
-            flags => "WITH_APACHE=yes WITH_APACHE2=yes BATCH=yes",
-        );
-    }
-
-    if ( $conf->{'install_2_modperl'} ) {
-        $freebsd->install_port( "mod_perl2" );
-    }
+    $freebsd->install_port( "php5",
+        flags => "WITH_APACHE=yes WITH_APACHE2=yes BATCH=yes",
+    );
 }
 
 sub conf_get_dir {
@@ -796,9 +784,10 @@ sub apache_conf_patch {
         if ( $line =~ q{#Include etc/apache22/extra/httpd-default.conf} ) {
             $line = "Include etc/apache22/extra/httpd-default.conf";
         };
-        if ( $line =~ q{#Include etc/apache22/extra/httpd-ssl.conf} ) {
-            $line = "Include etc/apache22/extra/httpd-ssl.conf";
-        };
+# not needed, all required SSL stuff is included in mail-toaster.conf
+        #if ( $line =~ q{#Include etc/apache22/extra/httpd-ssl.conf} ) {
+        #    $line = "Include etc/apache22/extra/httpd-ssl.conf";
+        #};
 
         # we want these only in mail-toaster.conf
         if ( $line =~ q{DocumentRoot "/usr/local/www/apache22/data"} ) {
@@ -869,7 +858,7 @@ sub restart {
     }
 
     if ( ! $restarted ) {
-        my $apachectl = $util->find_bin( "apachectl" ) 
+        my $apachectl = $util->find_bin( "apachectl" )
             or return $log->error( "couldn't restart Apache!");
 
         $util->syscmd( "$sudo $apachectl graceful" );
@@ -894,18 +883,18 @@ sub openssl_config_note {
 
     print "\n\t\tATTENTION! ATTENTION!
 
-If you don't like the default values being offered to you, or you 
-get tired of typing them in every time you generate a SSL cert, 
+If you don't like the default values being offered to you, or you
+get tired of typing them in every time you generate a SSL cert,
 edit your openssl.cnf file. ";
 
     if ( $OSNAME eq "darwin" ) {
         print "On Darwin, it lives at /System/Library/OpenSSL/openssl.cnf.\n";
-    } 
+    }
     elsif ( $OSNAME eq "freebsd" ) {
         print "On FreeBSD, it lives at /etc/ssl/openssl.cnf and /usr/local/openssl/openssl.cnf\n";
     }
     else {
-        print "On most platforms, it lives in 
+        print "On most platforms, it lives in
 /etc/ssl/openssl.cnf.\n";
     };
 
@@ -947,14 +936,12 @@ sub install_dsa_cert {
 }
 
 sub install_rsa_cert {
-
     my $self = shift;
 
     my %p = validate (@_, {
             'crtdir' => { type=>SCALAR },
             'keydir' => { type=>SCALAR },
-            'debug'  => { type=>SCALAR, optional=>1, default=>1, },
-            'test_ok'=> { type=>SCALAR, optional=>1, },
+            %std_opts
         },
     );
 
@@ -1009,7 +996,7 @@ Mail::Toaster::Apache - modules for installing, configuring and managing Apache
 Modules for working with Apache. Some are specific to Mail Toaster while most are generic, such as provisioning vhosts for an Apache 2 server. Using just these subs, Apache will be installed, SSL certs generated, and serving.
 
 
-=head1 DESCRIPTION 
+=head1 DESCRIPTION
 
 Perl methods for working with Apache. See METHODS.
 
@@ -1055,7 +1042,7 @@ Builds Apache from sources with DSO for all modules. Also installs mod_perl2 and
 
 Currently tested on FreeBSD and Mac OS X. On FreeBSD, the chosen version of php is installed. It installs both the PHP cli and mod_php Apache module. This is done because the SpamAssassin + SQL module requires pear-DB and the pear-DB port thinks it needs the lang/php port installed. There are other ports which also have this requirement so it's best to just have it installed.
 
-This script also builds default SSL certificates, based on your preferences in openssl.cnf (usually in /etc/ssl) and makes a few tweaks to your httpd.conf (for using PHP & perl scripts). 
+This script also builds default SSL certificates, based on your preferences in openssl.cnf (usually in /etc/ssl) and makes a few tweaks to your httpd.conf (for using PHP & perl scripts).
 
 Values in $conf are set in toaster-watcher.conf. Please refer to that file to see how you can influence your Apache build.
 
@@ -1081,7 +1068,7 @@ Builds and installs a RSA certificate.
 
 =item restart
 
-Restarts Apache. 
+Restarts Apache.
 
 On FreeBSD, we use the rc.d script if it's available because it's smarter than apachectl. Under some instances, sending apache a restart signal will cause it to crash and not restart. The control script sends it a TERM, waits until it has done so, then starts it back up.
 
@@ -1122,9 +1109,9 @@ None known. Report any to author.
 
 =head1 SEE ALSO
 
-The following are all man/perldoc pages: 
+The following are all man/perldoc pages:
 
- Mail::Toaster 
+ Mail::Toaster
  Mail::Toaster::Conf
  toaster.conf
  toaster-watcher.conf
@@ -1133,7 +1120,7 @@ The following are all man/perldoc pages:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2003-2008, The Network People, Inc. All Rights Reserved.
+Copyright (c) 2003-2012, The Network People, Inc. All Rights Reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
