@@ -3,14 +3,14 @@ use warnings;
 
 package Mail::Toaster::Ezmlm;
 
-our $VERSION = '5.26';
+our $VERSION = '5.33';
 
 use Params::Validate qw( :all );;
 use Pod::Usage;
 use English qw( -no_match_vars );
 
 use lib 'lib';
-use Mail::Toaster          5.26; 
+use Mail::Toaster          5.33;
 
 my ( $log, $util, %std_opts );
 
@@ -18,8 +18,9 @@ sub new {
     my $class = shift;
     my %p     = validate( @_,
         {   'log' => { type => OBJECT  },
-            fatal => { type => BOOLEAN, optional => 1, default => 1 },
-            debug => { type => BOOLEAN, optional => 1 },
+            fatal   => { type => BOOLEAN, optional => 1 },
+            debug   => { type => BOOLEAN, optional => 1 },
+            test_ok => { type => BOOLEAN, optional => 1 },
         }
     );
 
@@ -43,6 +44,7 @@ sub new {
         'test_ok' => { type => BOOLEAN, optional => 1 },
         'fatal'   => { type => BOOLEAN, optional => 1, default => $fatal },
         'debug'   => { type => BOOLEAN, optional => 1, default => $debug },
+        'quiet'   => { type => BOOLEAN, optional => 1, default => 0 },
     );
 
     return $self;
@@ -51,23 +53,23 @@ sub new {
 sub authenticate {
     my $self = shift;
 	my %p = validate ( @_, {
-	        'domain'   => { type=>SCALAR,  optional=>0, },
-	        'password' => { type=>SCALAR,  optional=>0, },
+	        'domain'   => SCALAR,
+	        'password' => SCALAR,
             %std_opts,
         },
 	);
 
-	my ($domain, $password, $fatal, $debug) 
-	    = ($p{'domain'}, $p{'password'}, $p{'fatal'}, $p{'debug'} );
+	my ($domain, $password ) = ( $p{domain}, $p{password} );
+    my %args = $log->get_std_args( %p );
 
-    print "attempting to authenticate postmaster\@$domain..." if $debug;
+    return $p{test_ok} if defined $p{test_ok};
 
-    $util->install_module( "vpopmail", debug => $debug,);
+    $util->install_module( "vpopmail", %args );
 
     require vpopmail;
 
     if ( vpopmail::vauth_user( 'postmaster', $domain, $password, undef ) ) {
-        print "ok.<br>" if $debug;
+        $log->audit( "authenticated postmaster\@$domain (ok)", %args);
         return 1;
     }
 
@@ -91,8 +93,8 @@ a user ($UID) that lacks permission to run this script. You can:<br>
 sub dir_check {
     my $self = shift;
     my %p = validate( @_, {
-            'dir'     => { type=>SCALAR, },
-            'br'      => { type=>SCALAR,  optional=>1, default=>'<br>' },
+            'dir' => SCALAR,
+            'br'  => { type=>SCALAR,  optional=>1, default=>'<br>' },
             %std_opts,
         },
     );
@@ -100,28 +102,23 @@ sub dir_check {
     my ( $dir, $br, $fatal, $debug )
         = ( $p{'dir'}, $p{'br'}, $p{'fatal'}, $p{'debug'} );
 
-    print "dir_check: checking: $dir..." if $debug;
-
     unless ( -d $dir && -r $dir ) {
-        print "ERROR: No read permissions to $dir: $! $br";
+        $log->error( "no read perms to $dir: $! $br",fatal=>0);
         return 0;
-    }
-    else {
-        print "ok.$br" if $debug;
-        return 1;
-    }
+    };
+
+    $log->audit( "dir_check: checking: $dir" );
+    return 1;
 }
 
 sub footer {
     shift;    # $self
-    my $VERSION = shift;
-
     print <<EOFOOTER;
 <hr> <p align="center"><font size="-2">
 		<a href="http://mail-toaster.org">Mail::Toaster::Ezmlm</a>
-      $VERSION -
-		&copy; <a href="http://www.tnpi.net">The Network People, Inc.</a> 1999-2008 <br><br>
-        <!--Donated to the toaster community by <a href="mailto:sam.mayes\@sudhian.com">Sam Mayes</a>--></font>
+      $Mail::Toaster::VERSION -
+		&copy; <a href="http://www.tnpi.net">The Network People, Inc.</a> 1999-2010 <br><br>
+        </font>
      </p>
   </body>
 </html>
@@ -192,6 +189,8 @@ sub logo {
     );
 
 	my $conf = $p{'conf'};
+    return $p{test_ok} if defined $p{test_ok};
+
     my $logo = $conf->{'web_logo_url'} or return '';
     my $alt  = $conf->{'web_logo_alt'} || '';
 
@@ -200,7 +199,7 @@ sub logo {
 
 sub process_cgi {
     my $self = shift;
-    
+
     my %p = validate( @_, {
             'list_dir' => { type=>SCALAR,  optional=>1, },
             'br'       => { type=>SCALAR,  optional=>1, default=>'<br>' },
@@ -298,7 +297,7 @@ sub process_cgi {
             $self->subs_list( list=>$list, list_dir=>$list_dir, br=>$br, debug=>$debug );
         }
         elsif ( $action eq "add" ) {
-            my @reqs = split( "\n", param('addresses') );
+            my @reqs = split( /\n/, param('addresses') );
             print "reqs: @reqs<br>" if $debug;
             my $requested = \@reqs;
             $self->subs_add( list=>$list, list_dir=>$list_dir, requested=>$requested, br=>$br );
@@ -311,26 +310,30 @@ sub process_cgi {
         print "missing auth, action, or lists<br>";
     }
 
-    $self->footer($VERSION);
+    $self->footer();
 }
 
 sub process_shell {
     my $self = shift;
-    use vars qw($opt_a $opt_d $opt_f $opt_v $list $debug);
+    my %p     = validate( @_, { %std_opts } );
+    use vars qw($opt_a $opt_d $opt_f $opt_v $list );
+    my $debug = $p{debug};
 
-    $util->install_module( "Mail::Ezmlm", debug => 0,);
+    $util->install_module( "Mail::Ezmlm", %p );
     require Mail::Ezmlm;
 
     use Getopt::Std;
     getopts('a:d:f:v');
 
     my $br = "\n";
-    $debug = $opt_v ? 1 : 0;
+    $debug = $opt_v if defined $opt_v;
 
     # set up based on command line options
     my $list_dir;
     $list_dir = $opt_d if $opt_d;
 
+    return $p{test_ok} if defined $p{test_ok};
+
     # set a default list dir if not already set
     if (! $list_dir) {
         print "You didn't set the list directory! Use the -d option!\n";
@@ -388,14 +391,14 @@ sub subs_add {
         },
     );
 
-	my ($list, $list_dir, $requested, $br, $fatal, $debug) 
+	my ($list, $list_dir, $requested, $br, $fatal, $debug)
         = ( $p{'list'}, $p{'list_dir'}, $p{'requested'}, $p{'br'}, $p{'fatal'}, $p{'debug'} );
 	
 	if ( ! -d $list_dir ) {
         print "ERROR: Aiiieee, the list $list_dir is missing!\n" if $debug;
         return 0;
     }
-    
+
     my ( $duplicates, $success, $failed, @list_dups, @list_success, @list_fail );
 
     print "$br";
@@ -481,10 +484,6 @@ sub subs_list {
 1;
 __END__
 
-# =head1 ACKNOWLEDGEMENTS
-#
-# Funded by Sam Mayes (sam.mayes@sudhian.com) and donated to the toaster community
-# I'll add this back in if Sam ever pays.
 
 =head1 NAME
 
@@ -502,7 +501,7 @@ Mail::Toaster::Ezmlm - a batch processing tool for ezmlm mailing lists
 
 =head1 DESCRIPTION
 
-Ezmlm.cgi is a command line and CGI application that allows a domain administrator (ie, postmaster@example.com) to add, remove, and list batches of email addresses. You can use this utility to subscribe lists of email addresses, delete a list of addresses, or simply retrieve a list of subscribers. 
+Ezmlm.cgi is a command line and CGI application that allows a domain administrator (ie, postmaster@example.com) to add, remove, and list batches of email addresses. You can use this utility to subscribe lists of email addresses, delete a list of addresses, or simply retrieve a list of subscribers.
 
 
 =head1 DEPENDENCIES
@@ -510,7 +509,7 @@ Ezmlm.cgi is a command line and CGI application that allows a domain administrat
  some functions depend on Mail::Ezmlm;
  authentication depends on "vpopmail" (a perl extension)
 
-If you need to run ezmlm.cgi suid, which is likely the case, then hacks to Mail::Ezmlm are required for the "list" function to work in taint mode. Also, for a perl script to run suid, you must have suidperl installed. Another (better) approach is to use Apache suexec instead of suidperl. 
+If you need to run ezmlm.cgi suid, which is likely the case, then hacks to Mail::Ezmlm are required for the "list" function to work in taint mode. Also, for a perl script to run suid, you must have suidperl installed. Another (better) approach is to use Apache suexec instead of suidperl.
 
 
 =head1 METHODS
@@ -541,7 +540,7 @@ return 0 if not, return 1 if OK.
 
 =item lists_get
 
-Get a list of Ezmlm lists for a given mail directory. This is designed to work with vpopmail where all the list for example.com are in ~vpopmail/domains. 
+Get a list of Ezmlm lists for a given mail directory. This is designed to work with vpopmail where all the list for example.com are in ~vpopmail/domains.
 
     $ezmlm->lists_get("example.com");
 
@@ -554,7 +553,7 @@ Put the logo on the HTML page. Sets the URL from $conf.
 
 $conf is values from toaster.conf.
 
- Example: 
+ Example:
     $ezmlm->logo(
         web_logo_url => 'http://www.tnpi.net/images/head.jpg',
         web_log_alt  => 'tnpi.net logo',
@@ -578,8 +577,8 @@ Get input from the command line options and proceed accordingly.
 Subcribe a user (or list of users) to a mailing list.
 
    $ezmlm->subs_add(
-       list      => $list_name, 
-       list_dir  => $list_dir, 
+       list      => $list_name,
+       list_dir  => $list_dir,
        requested => $address_list
     );
 
@@ -607,9 +606,9 @@ None known. Report any to author.
 
 =head1 SEE ALSO
 
-The following are all man/perldoc pages: 
+The following are all man/perldoc pages:
 
- Mail::Toaster 
+ Mail::Toaster
  Mail::Toaster::Conf
  toaster.conf
  toaster-watcher.conf
@@ -619,7 +618,7 @@ The following are all man/perldoc pages:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2008, The Network People, Inc.  All rights reserved.
+Copyright (c) 2005-2012, The Network People, Inc.  All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
