@@ -3,17 +3,18 @@ package Mail::Toaster::FreeBSD;
 use strict;
 use warnings;
 
-our $VERSION = '5.26';
+our $VERSION = '5.33';
 
-use Cwd;
+#use Cwd; # included with POSIX
 use Carp;
 use File::Copy;
 use Params::Validate qw( :all );
+use POSIX;
 
 use vars qw($err);
 
 use lib 'lib';
-use Mail::Toaster 5.26;
+use Mail::Toaster 5.33;
 my ($toaster, $log, $util, %std_opts );
 
 sub new {
@@ -45,6 +46,7 @@ sub new {
         'test_ok' => { type => BOOLEAN, optional => 1 },
         'fatal'   => { type => BOOLEAN, optional => 1, default => $fatal },
         'debug'   => { type => BOOLEAN, optional => 1, default => $debug },
+        'quiet'   => { type => BOOLEAN, optional => 1, default => 0 },
     );
 
     return $self;
@@ -53,15 +55,15 @@ sub new {
 sub drive_spin_down {
     my $self = shift;
     my %p = validate( @_, { 'drive' => SCALAR, %std_opts } );
+    my %args = $toaster->get_std_args( %p );
 
     my $drive = $p{'drive'};
-    my %args = ( debug => $p{debug}, fatal => $p{fatal} );
 
     return $p{'test_ok'} if defined $p{'test_ok'};
 
     #TODO: see if the drive exists!
 
-    my $camcontrol = $util->find_bin( "camcontrol", %args) 
+    my $camcontrol = $util->find_bin( "camcontrol", %args)
         or return $log->error( "couldn't find camcontrol", %args );
 
     print "spinning down backup drive $drive...";
@@ -74,9 +76,9 @@ sub get_port_category {
     my $self = shift;
     my $port = shift or die "missing port in request\n";
 
-    my ($path) = </usr/ports/*/$port/distinfo>;
+    my ($path) = glob("/usr/ports/*/$port/distinfo");
     if ( ! $path ) {
-        ($path) = </usr/ports/*/$port/Makefile>;
+        ($path) = glob("/usr/ports/*/$port/Makefile");
     };
 #warn "path: $path\n";
     return if ! $path;
@@ -89,11 +91,7 @@ sub get_version {
     my $self  = shift;
     my $debug = shift;
 
-    my $uname = $util->find_bin( "uname", debug => 0 );
-    print "found uname: $uname\n" if $debug;
-
-    my $version = `$uname -r`;
-    chomp $version;
+    my (undef, undef, $version) = POSIX::uname;
     print "version is $version\n" if $debug;
 
     return $version;
@@ -128,7 +126,7 @@ sub install_port {
     $port_dir =~ s/::/-/g if $port_dir =~ /::/;
 
     my $start_directory = Cwd::getcwd();
-		my $category = $p{category} || $self->get_port_category($portname) 
+		my $category = $p{category} || $self->get_port_category($portname)
             or die "unable to find port directory for port $portname\n";
 
 		my $path = "/usr/ports/$category/$port_dir";
@@ -143,7 +141,7 @@ sub install_port {
             if ( $def =~ /=/ ) {             # DEFINE=VALUE format, use as is
                 $make_defines .= " $def ";
             }
-            else { 
+            else {
                 $make_defines .= " -D$def "; # otherwise, prepend the -D flag
             }
         }
@@ -153,27 +151,18 @@ sub install_port {
         $self->port_options( port => $portname, opts => $options );
     }
 
-    if ( $portname eq "qmail" ) {
-        $util->syscmd( "make clean && make $make_defines install && make clean");
-    }
-    elsif ( $portname eq "ezmlm-idx" ) {
-        $util->syscmd( "make clean && make $make_defines install" );
+    # reset our PATH, to make sure we use our system supplied tools
+    $ENV{PATH} = "/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin";
+
+    # the vast majority of ports work great this way
+    print "running: make $make_defines install clean\n";
+    system "make clean";
+    system "make $make_defines";
+    system "make $make_defines install";
+    if ( $portname eq "ezmlm-idx" ) {
         copy( "work/ezmlm-0.53/ezmlmrc", "/usr/local/bin" );
-        $util->syscmd( "make clean" );
-    }
-    else {
-
-        # reset our PATH, to make sure we use our system supplied tools
-        $ENV{PATH}
-            = "/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin";
-
-        # the vast majority of ports work great this way
-        print "running: make $make_defines install clean\n";
-        system "make clean";
-        system "make $make_defines";
-        system "make $make_defines install";
-        system "make clean";
     }
+    system "make clean";
 
     # return to our original working directory
     chdir($start_directory);
@@ -202,8 +191,7 @@ EO_PERL_MODULE_MANUAL
 sub is_port_installed {
     my $self = shift;
     my $port = shift or return $log->error("missing port/package name", fatal=>0);
-    my %p    = validate(
-        @_,
+    my %p    = validate( @_,
         {   'alt' => { type => SCALAR | UNDEF, optional => 1 },
             %std_opts,
         },
@@ -219,13 +207,13 @@ sub is_port_installed {
 
     my $pkg_info = $util->find_bin( 'pkg_info', debug => 0 );
     my @packages = `pkg_info`; chomp @packages;
-    my @matches = grep {/^$port/} @packages;
-    if ( scalar @matches == 0 ) {
-        @matches = grep {/^$alt/} @packages;
-    };   
+    my @matches = grep {/^$port\-/} @packages;
+    if ( scalar @matches == 0 ) { @matches = grep {/^$port/} @packages; };
+    if ( scalar @matches == 0 ) { @matches = grep {/^$alt\-/ } @packages; };
+    if ( scalar @matches == 0 ) { @matches = grep {/^$alt/ } @packages; };
     return if scalar @matches == 0; # no matches
     $toaster->audit( "WARN: found multiple matches for port $port",debug=>1)
-        if scalar @matches != 1;
+        if scalar @matches > 1;
 
     my ($installed_as) = split(/\s/, $matches[0]);
     $toaster->audit( "found port $port installed as $installed_as",debug=>$p{debug} );
@@ -276,7 +264,7 @@ sub install_package {
     );
 
     my ( $alt, $pkg_url ) = ( $p{'alt'}, $p{'url'} );
-    my %args = ( debug => $p{debug}, fatal => $p{fatal} );
+    my %args = $toaster->get_std_args( %p );
 
     return $util->error("sorry, but I really need a package name!") if !$package;
 
@@ -363,7 +351,7 @@ sub port_options {
     );
 
     my ( $port, $opts ) = ( $p{port}, $p{opts} );
-    my %args = ( debug => $p{debug}, fatal => $p{fatal} );
+    my %args = $toaster->get_std_args( %p );
 
     return $p{test_ok} if defined $p{test_ok};
 
@@ -395,7 +383,7 @@ sub portsnap {
     my $self = shift;
     my %p    = validate( @_, { %std_opts, },);
 
-    my %args = ( debug => $p{debug}, fatal => $p{fatal} );
+    my %args = $toaster->get_std_args( %p );
 
     return $p{'test_ok'} if defined $p{'test_ok'};
 
@@ -434,7 +422,7 @@ sub portsnap {
         print "\a
     COFFEE BREAK TIME: this step will take a while, dependent on how fast your
     disks are. After this initial extract, portsnap updates are much quicker than
-    doing a cvsup and require less bandwidth (good for you, and the FreeBSD 
+    doing a cvsup and require less bandwidth (good for you, and the FreeBSD
     servers). Please be patient.\n\n";
         sleep 2;
         system $portsnap, "extract";
@@ -461,6 +449,7 @@ sub conf_check {
     my $check = $p{check};
     my $line  = $p{line};
     my $file  = $p{file} || "/etc/rc.conf";
+    $log->audit("conf_check: looking for $check");
 
     return $p{'test_ok'} if defined $p{'test_ok'};
 
@@ -469,7 +458,7 @@ sub conf_check {
     @lines = $util->file_read( $file ) if -f $file;
     foreach ( @lines ) {
         next if $_ !~ /^$check\=/;
-        return $log->audit("conf_check: no change to $check") if $_ eq $line;
+        return $log->audit("\tno change") if $_ eq $line;
         $log->audit("\tchanged:\n$_\n\tto:\n$line\n" );
         $_ = $line;
         $changes++;
@@ -511,7 +500,7 @@ Usage examples for each subroutine are included.
 
 =item is_port_installed
 
-Checks to see if a port is installed. 
+Checks to see if a port is installed.
 
     $fbsd->is_port_installed( "p5-CGI" );
 
@@ -523,7 +512,7 @@ Checks to see if a port is installed.
 
  result:
    0 - not installed
-   1 - if installed 
+   1 - if installed
 
 
 =item jail_create
@@ -532,7 +521,7 @@ Checks to see if a port is installed.
 
  arguments required:
     ip        - 10.0.1.1
-    
+
  arguments optional:
     hostname  - jail36.example.com,
     jail_home - /home/jail,
@@ -547,16 +536,16 @@ Here's an example of how I use it:
 
     ifconfig fxp0 inet alias 10.0.1.175/32
 
-    perl -e 'use Mail::Toaster::FreeBSD;  
-         my $fbsd = Mail::Toaster::FreeBSD->new; 
+    perl -e 'use Mail::Toaster::FreeBSD;
+         my $fbsd = Mail::Toaster::FreeBSD->new;
          $fbsd->jail_create( ip=>"10.0.1.175" )';
 
-After running $fbsd->jail_create, you need to set up the jail. 
+After running $fbsd->jail_create, you need to set up the jail.
 At the very least, you need to:
 
     1. set root password
     2. create a user account
-    3. get remote root 
+    3. get remote root
         a) use sudo (pkg_add -r sudo; visudo)
         b) add user to wheel group (vi /etc/group)
         c) modify /etc/ssh/sshd_config to permit root login
@@ -570,8 +559,8 @@ Here's how I set up my jails:
     rehash; visudo
     sh /etc/rc
 
-Ssh into the jail from another terminal. Once successfully 
-logged in with root privs, you can drop the initial shell 
+Ssh into the jail from another terminal. Once successfully
+logged in with root privs, you can drop the initial shell
 and access the jail directly.
 
 Read the jail man pages for more details. Read the perl code
@@ -611,17 +600,17 @@ jail_home defaults to "/home/jail".
 
 Here's an example of how I use it:
 
-    perl -e 'use Mail::Toaster::FreeBSD; 
+    perl -e 'use Mail::Toaster::FreeBSD;
       $fbsd = Mail::Toaster::FreeBSD->new;
       $fbsd->jail_start( ip=>"10.0.1.175" )';
 
 
-    
+
 =item install_port
 
     $fbsd->install_port( "openldap" );
 
-That's it. Really. Well, OK, sometimes it can get a little more complex. install_port checks first to determine if a port is already installed and if so, skips right on by. It is very intelligent that way. However, sometimes port maintainers do goofy things and we need to override settings that would normally work. A good example of this is currently openldap. 
+That's it. Really. Well, OK, sometimes it can get a little more complex. install_port checks first to determine if a port is already installed and if so, skips right on by. It is very intelligent that way. However, sometimes port maintainers do goofy things and we need to override settings that would normally work. A good example of this is currently openldap.
 
 If you want to install OpenLDAP 2, then you can install from any of:
 
@@ -631,11 +620,11 @@ If you want to install OpenLDAP 2, then you can install from any of:
 		/usr/ports/net/openldap24-client
 
 So, a full complement of settings could look like:
-  
+
     $freebsd->install_port( "openldap-client",
 		dir   => "openldap24-server",
 		check => "openldap-client-2.4",
-		flags => "NOPORTDOCS=true", 
+		flags => "NOPORTDOCS=true",
 		fatal => 0,
 	);
 
@@ -649,7 +638,7 @@ So, a full complement of settings could look like:
    fatal
    debug
 
- NOTES:   
+ NOTES:
 
 #1 - On rare occasion, a port will get installed as a name other than the ports name. Of course, that wreaks all sorts of havoc so when one of them nasties is found, you can optionally pass along a fourth parameter which can be used as the port installation name to check with.
 
@@ -658,7 +647,7 @@ So, a full complement of settings could look like:
 
 	$fbsd->install_package( "ispell" );
 
-Suggested usage: 
+Suggested usage:
 
 	unless ( $fbsd->install_package( "ispell" ) ) {
 		$fbsd->install_port( "ispell" );
@@ -686,7 +675,7 @@ Updates the FreeBSD ports tree (/usr/ports/).
 
  arguments required:
    conf - a hashref
- 
+
 See the docs for toaster-watcher.conf for complete details.
 
 
@@ -713,9 +702,9 @@ Needs more documentation.
 
 =head1 SEE ALSO
 
-The following are all man/perldoc pages: 
+The following are all man/perldoc pages:
 
- Mail::Toaster 
+ Mail::Toaster
  Mail::Toaster::Conf
  toaster.conf
  toaster-watcher.conf
@@ -726,7 +715,7 @@ The following are all man/perldoc pages:
 
 =head1 COPYRIGHT
 
-Copyright 2003-2009, The Network People, Inc. All Rights Reserved.
+Copyright 2003-2012, The Network People, Inc. All Rights Reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
